
# Class: NeatConfiguration


Root class for the schema.

URI: [https://w3id.org/neat/NeatConfiguration](https://w3id.org/neat/NeatConfiguration)


[![img](https://yuml.me/diagram/nofunky;dir:TB/class/[GraphDataConfiguration]<graph_data%200..1-++[NeatConfiguration],[GraphDataConfiguration])](https://yuml.me/diagram/nofunky;dir:TB/class/[GraphDataConfiguration]<graph_data%200..1-++[NeatConfiguration],[GraphDataConfiguration])

## Attributes


### Own

 * [➞graph_data](neatConfiguration__graph_data.md)  <sub>0..1</sub>
     * Description: Configuration for graph data.
     * Range: [GraphDataConfiguration](GraphDataConfiguration.md)
